SearchCursor class

Constructors

SearchCursor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getSearchCursor(CodeMirror editor, String value, {Position? start, Map? options}) → SearchCursorContainer
Retrieve the search cursor from the editor instance.