SearchCursorContainer class

Inheritance

Properties

atOccurrence → bool
no setter
doc → Doc
no setter
hashCode → int
The hash code for this object.
no setterinherited
jsProxy → JsObject?
finalinherited
pos → Position
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String methodName) → dynamic
inherited
callArg(String methodName, dynamic arg) → dynamic
inherited
callArgs(String methodName, List args) → dynamic
inherited
dispose() → void
This method should be called if any events listeners were added to the object.
inherited
findNext() → bool
Search forward from the current position
findPrevious() → bool
Search backward from the current position
from() → Position
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent<T>(String eventName, {int argCount = 1}) → Stream<T?>
inherited
replace(String text, {dynamic origin}) → String
to() → Position
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited